@@ -20,7 +20,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-__version__ = '1.1.1'  # Remember to change in setup.py as well!
+__version__ = '1.1.4'  # Remember to change in setup.py as well!
 __author__ = 'Raphaël Barrois <raphael.barrois@polytechnique.org>'
 
 from base import (
@@ -31,15 +31,20 @@ from base import (
     build,
     create,
     stub,
+    generate,
+    simple_generate,
     make_factory,
 
     build_batch,
     create_batch,
     stub_batch,
+    generate_batch,
+    simple_generate_batch,
 
     BUILD_STRATEGY,
     CREATE_STRATEGY,
     STUB_STRATEGY,
+    use_strategy,
 
     DJANGO_CREATION,
     NAIVE_BUILD,
@@ -48,15 +53,22 @@ from base import (
 
 from declarations import (
     LazyAttribute,
+    Iterator,
+    InfiniteIterator,
     Sequence,
     LazyAttributeSequence,
     SelfAttribute,
     ContainerAttribute,
     SubFactory,
+    PostGeneration,
+    RelatedFactory,
 
     lazy_attribute,
+    iterator,
+    infinite_iterator,
     sequence,
     lazy_attribute_sequence,
     container_attribute,
+    post_generation,
 )
 
