@@ -21,6 +21,11 @@
 # THE SOFTWARE.
 
 
+import itertools
+
+from factory import utils
+
+
 class OrderedDeclaration(object):
     """A factory declaration.
 
@@ -110,6 +115,34 @@ class SelfAttribute(OrderedDeclaration):
         return deepgetattr(obj, self.attribute_name, self.default)
 
 
+class Iterator(OrderedDeclaration):
+    """Fill this value using the values returned by an iterator.
+
+    Warning: the iterator should not end !
+
+    Attributes:
+        iterator (iterable): the iterator whose value should be used.
+    """
+
+    def __init__(self, iterator):
+        super(Iterator, self).__init__()
+        self.iterator = iter(iterator)
+
+    def evaluate(self, sequence, obj, containers=()):
+        return self.iterator.next()
+
+
+class InfiniteIterator(Iterator):
+    """Same as Iterator, but make the iterator infinite by cycling at the end.
+
+    Attributes:
+        iterator (iterable): the iterator, once made infinite.
+    """
+
+    def __init__(self, iterator):
+        return super(InfiniteIterator, self).__init__(itertools.cycle(iterator))
+
+
 class Sequence(OrderedDeclaration):
     """Specific OrderedDeclaration to use for 'sequenced' fields.
 
@@ -211,12 +244,123 @@ class SubFactory(OrderedDeclaration):
             defaults.update(extra)
         defaults['__containers'] = containers
 
-        attrs = self.factory.attributes(create, defaults)
-
         if create:
-            return self.factory.create(**attrs)
+            return self.factory.create(**defaults)
         else:
-            return self.factory.build(**attrs)
+            return self.factory.build(**defaults)
+
+
+class PostGenerationDeclaration(object):
+    """Declarations to be called once the target object has been generated.
+
+    Attributes:
+        extract_prefix (str): prefix to use when extracting attributes from
+            the factory's declaration for this declaration. If empty, uses
+            the attribute name of the PostGenerationDeclaration.
+    """
+
+    def __init__(self, extract_prefix=None):
+        self.extract_prefix = extract_prefix
+
+    def extract(self, name, attrs):
+        """Extract relevant attributes from a dict.
+
+        Args:
+            name (str): the name at which this PostGenerationDeclaration was
+                defined in the declarations
+            attrs (dict): the attribute dict from which values should be
+                extracted
+
+        Returns:
+            (object, dict): a tuple containing the attribute at 'name' (if
+                provided) and a dict of extracted attributes
+        """
+        extracted = attrs.pop(name, None)
+        if self.extract_prefix:
+            extract_prefix = self.extract_prefix
+        else:
+            extract_prefix = name
+        kwargs = utils.extract_dict(extract_prefix, attrs)
+        return extracted, kwargs
+
+    def call(self, obj, create, extracted=None, **kwargs):
+        """Call this hook; no return value is expected.
+
+        Args:
+            obj (object): the newly generated object
+            create (bool): whether the object was 'built' or 'created'
+            extracted (object): the value given for <extract_prefix> in the
+                object definition, or None if not provided.
+            kwargs (dict): declarations extracted from the object
+                definition for this hook
+        """
+        raise NotImplementedError()
+
+
+class PostGeneration(PostGenerationDeclaration):
+    """Calls a given function once the object has been generated."""
+    def __init__(self, function, extract_prefix=None):
+        super(PostGeneration, self).__init__(extract_prefix)
+        self.function = function
+
+    def call(self, obj, create, extracted=None, **kwargs):
+        self.function(obj, create, extracted, **kwargs)
+
+
+def post_generation(extract_prefix=None):
+    def decorator(fun):
+        return PostGeneration(fun, extract_prefix=extract_prefix)
+    return decorator
+
+
+class RelatedFactory(PostGenerationDeclaration):
+    """Calls a factory once the object has been generated.
+
+    Attributes:
+        factory (Factory): the factory to call
+        defaults (dict): extra declarations for calling the related factory
+        name (str): the name to use to refer to the generated object when
+            calling the related factory
+    """
+
+    def __init__(self, factory, name='', **defaults):
+        super(RelatedFactory, self).__init__(extract_prefix=None)
+        self.factory = factory
+        self.name = name
+        self.defaults = defaults
+
+    def call(self, obj, create, extracted=None, **kwargs):
+        passed_kwargs = dict(self.defaults)
+        passed_kwargs.update(kwargs)
+        if self.name:
+            passed_kwargs[self.name] = obj
+        self.factory.simple_generate(create, **passed_kwargs)
+
+
+class PostGenerationMethodCall(PostGenerationDeclaration):
+    """Calls a method of the generated object.
+
+    Attributes:
+        method_name (str): the method to call
+        method_args (list): arguments to pass to the method
+        method_kwargs (dict): keyword arguments to pass to the method
+
+    Example:
+        class UserFactory(factory.Factory):
+            ...
+            password = factory.PostGenerationMethodCall('set_password', password='')
+    """
+    def __init__(self, method_name, extract_prefix=None, *args, **kwargs):
+        super(PostGenerationMethodCall, self).__init__(extract_prefix)
+        self.method_name = method_name
+        self.method_args = args
+        self.method_kwargs = kwargs
+
+    def call(self, obj, create, extracted=None, **kwargs):
+        passed_kwargs = dict(self.method_kwargs)
+        passed_kwargs.update(kwargs)
+        method = getattr(obj, self.method_name)
+        method(*self.method_args, **passed_kwargs)
 
 
 # Decorators... in case lambdas don't cut it
@@ -224,6 +368,14 @@ class SubFactory(OrderedDeclaration):
 def lazy_attribute(func):
     return LazyAttribute(func)
 
+def iterator(func):
+    """Turn a generator function into an iterator attribute."""
+    return Iterator(func())
+
+def infinite_iterator(func):
+    """Turn a generator function into an infinite iterator attribute."""
+    return InfiniteIterator(func())
+
 def sequence(func):
     return Sequence(func)
 
